pub enum DevicePattern {
WearTak,
WearOs,
Hive,
Unknown,
}Expand description
Patterns that indicate a device may rotate its BLE address
Variants
WearTak
WearTAK on WearOS (WT-WEAROS-XXXX)
WearOs
Generic WearOS device (WEAROS-XXXX)
Hive
HIVE mesh device (HIVE_MESH-XXXX or HIVE-XXXX)
Unknown
Unknown pattern (may still rotate addresses)
Implementations
Sourceimpl DevicePattern
impl DevicePattern
Sourcepub fn rotates_addresses(&self) -> bool
pub fn rotates_addresses(&self) -> bool
Check if this device type is known to rotate addresses